@@ -8,13 +8,16 @@ from pyrasta.crs import srs_from
 from pyrasta.io_.files import VrtTempFile, _copy_to_file
 from pyrasta.tools import _gdal_temp_dataset, _return_raster, _clone_gdal_dataset
 
-# from osgeo import gdal_array
-
 import affine
-import gdal
 from pyrasta.tools.mapping import NUMPY_TO_GDAL
 
 
+try:
+    from osgeo import gdal
+except ImportError:
+    import gdal
+
+
 @_return_raster
 def _align_raster(in_raster, out_file, on_raster):
     """ Align raster on other raster
